@@ -1,6 +1,6 @@
 package Zoidberg::Fish;
 
-our $VERSION = '0.90';
+our $VERSION = '0.92';
 
 use strict;
 use Zoidberg::Utils 'error';
@@ -144,6 +144,10 @@ named subroutine in the current object.
 Removes a command. Wipes the stacks for the named commands
 of all routines belonging to this plugin.
 
+=item C<add_expansion(regex_ref => sub { ... })>
+
+=item C<wipe_expansions()>
+
 =cut
 
 sub add_events { # get my events unless @_ ?
@@ -176,6 +180,14 @@ sub wipe_commands {
 	tied( %{$$self{shell}{commands}} )->wipe( $$self{zoidname}, @_ );
 }
 
+sub add_expansion {
+	todo()
+}
+
+sub wipe_expansions {
+	todo()
+}
+
 # ########### #
 # other stuff #
 # ########### #
