@@ -2,10 +2,10 @@
 	module => 'Zoidberg::Fish::Log',
 	config => {
 		loghist  => 1, # if false new commands are ignored
-		logfile  => '~/.history.yaml',
-		maxlines => 150,
+		logfile  => '~/.zoid.log.yaml',
+		maxlines => 128,
 		no_duplicates => 1,
+		keep => { pwd => 10 },
 	},
-	import => [qw/read_history/],
-	# TODO export => [qw/fc history/]
+	export => [qw/fc history log/],
 };
